@@ -15,6 +15,8 @@ use tokio::{
 };
 use tracing::{Instrument, Level};
 
+#[cfg(feature = "cookie")]
+use crate::middleware::CookieJarManager;
 use crate::{
     listener::{Acceptor, Listener},
     web::RemoteAddr,
@@ -57,7 +59,8 @@ impl<T: Acceptor> Server<T> {
         signal: impl Future<Output = ()>,
         timeout: Option<Duration>,
     ) -> IoResult<()> {
-        let ep = Arc::new(ep.map_to_response().into_endpoint());
+        let ep = warps_endpoint(ep.into_endpoint());
+        let ep = Arc::new(ep.map_to_response());
         let Server { mut acceptor } = self;
         let alive_connections = Arc::new(AtomicUsize::new(0));
         let notify = Arc::new(Notify::new());
@@ -166,3 +169,11 @@ async fn serve_connection(
     let conn = conn.with_upgrades();
     let _ = conn.await;
 }
+
+#[doc(hidden)]
+pub fn warps_endpoint(ep: impl Endpoint) -> impl Endpoint<Output = Response> {
+    println!("1");
+    #[cfg(feature = "cookie")]
+    let ep = ep.with(CookieJarManager);
+    ep.map_to_response()
+}
